YARP 2.1.5 (2007-06-04)                                                {#v2_1_5}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.4...v2.1.5`):

```
    59	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    23	Lorenzo Natale <lorenzo.natale@iit.it>
    15	Alessandro Scalzo <alessandro.scalzo@iit.it>
    10	YARP Developers <yarp0-devel@lists.sourceforge.net>
     8	Alexandre Bernardino <alex@isr.ist.utl.pt>
     7	Carlos Beltran-Gonzalez <carlos.beltran@iit.it>
     4	Francesco Nori <francesco.nori@iit.it>
     2	Jonas Ruesch <ruesch@ifi.uzh.ch>
```
